@@ -1,6 +1,6 @@
 /*
 
-Copyright (c) 1997-2001, Perforce Software, Inc.  All rights reserved.
+Copyright (c) 1997-2004, Perforce Software, Inc.  All rights reserved.
 
 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met:
@@ -389,6 +389,30 @@ ClientUserPerl::OutputText( const_char *data, int length )
 	LEAVE;
 }
 
+void
+ClientUserPerl::OutputBinary( const_char *data, int length )
+{
+	dTHX;
+	dSP;
+	ENTER;
+	SAVETMPS;
+	PUSHMARK(SP);
+
+	// Put args on stack
+	XPUSHs( perlUI );
+	XPUSHs( sv_2mortal( newSVpv( (char *)data, 0 ) ) );
+	XPUSHs( sv_2mortal( newSViv( length ) ) );
+	PUTBACK;
+
+	PERL_CALL_METHOD( "OutputBinary", G_VOID );
+
+	// Clean up stack for return
+	SPAGAIN;
+	PUTBACK;
+	FREETMPS;
+	LEAVE;
+}
+
 
 /*
  * Prompts the user for input. If noEcho is true, then we call the 
